Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .cls import TypedConfig # noqa: F401 imported for library reasons

9 from .core import load_into # noqa: F401 imported for library reasons

10 from .singleton import ( # noqa: F401 imported for library reasons

11 Singleton,

12 SingletonMeta,

13)